pub struct Statistics {
pub total_bytes: u64,
pub file_count: usize,
pub last_appended_at: Option<TimestampAsNanoseconds>,
}Expand description
Statistics about a set of files contained in a collection.
Fields
total_bytes: u64The total number of bytes contained within the path queried. This only counts bytes that would be returned when reading the contents of files. No metadata information is included in this calculation.
file_count: usizeThe number of files contained within the path queried.
last_appended_at: Option<TimestampAsNanoseconds>The last timestamp data was appended to a file within the path queried.
This contains None if there is no data present.